@@ -17,22 +17,22 @@ from dependency_injector import providers as providers
 from krules_core.tests.subject.sqlite_storage import SQLLiteSubjectStorage
 
 from .route.dispatcher import BaseDispatcher
-from .route.router import MessageRouter
+from .route.router import EventRouter
 from .subject.storaged_subject import Subject
 from .exceptions_dumpers import ExceptionsDumpers
 
 import logging
 logger = logging.getLogger(__name__)
 
-settings_factory = providers.Singleton(lambda: {})
+configs_factory = providers.Singleton(lambda: {})
 
 # for testing/development only
 subject_storage_factory = providers.Factory(lambda x: SQLLiteSubjectStorage(x, ":memory:"))
 
 subject_factory = providers.Factory(Subject)
-results_rx_factory = providers.Singleton(rx.subjects.ReplaySubject)
-message_router_factory = providers.Singleton(MessageRouter)
-message_dispatcher_factory = providers.Singleton(BaseDispatcher)
+proc_events_rx_factory = providers.Singleton(rx.subjects.ReplaySubject)
+event_router_factory = providers.Singleton(EventRouter)
+event_dispatcher_factory = providers.Singleton(BaseDispatcher)
 exceptions_dumpers_factory = providers.Singleton(ExceptionsDumpers)
 
 
